pub type ConsoleAuthConfirmationHandler = UserProvidedAuthConfirmationHandler<Stdin, Stdout>;Expand description
Ask the user for the totp token from the terminal
Aliased Type
pub struct ConsoleAuthConfirmationHandler { /* private fields */ }pub type ConsoleAuthConfirmationHandler = UserProvidedAuthConfirmationHandler<Stdin, Stdout>;Ask the user for the totp token from the terminal
pub struct ConsoleAuthConfirmationHandler { /* private fields */ }